fpclassify(3) says:
The symbols isinff(), and isnanf() are provided as compatibility aliases
to isinf(), and isnan(), respectively, and their uses are deprecated.
Similarly, finite() and finitef() are deprecated versions of isfinite().
So let's use the preferred names in libm.
ok?
Philip
Index: noieee_src/n_atan2.c
===================================================================
RCS file: /cvs/src/lib/libm/noieee_src/n_atan2.c,v
retrieving revision 1.18
diff -u -p -r1.18 n_atan2.c
--- noieee_src/n_atan2.c 15 Jul 2013 04:08:26 -0000 1.18
+++ noieee_src/n_atan2.c 10 Sep 2016 20:30:34 -0000
@@ -151,7 +151,7 @@ atan2(double y, double x)
signx = copysign(one,x) ;
/* if x is 1.0, goto begin */
- if(x==1) { y=copysign(y,one); t=y; if(finite(t)) goto begin;}
+ if(x==1) { y=copysign(y,one); t=y; if(isfinite(t)) goto begin;}
/* when y = 0 */
if(y==zero) return((signx==one)?y:copysign(PI,signy));
@@ -160,14 +160,14 @@ atan2(double y, double x)
if(x==zero) return(copysign(PIo2,signy));
/* when x is INF */
- if(!finite(x))
- if(!finite(y))
+ if(!isfinite(x))
+ if(!isfinite(y))
return(copysign((signx==one)?PIo4:3*PIo4,signy));
else
return(copysign((signx==one)?zero:PI,signy));
/* when y is INF */
- if(!finite(y)) return(copysign(PIo2,signy));
+ if(!isfinite(y)) return(copysign(PIo2,signy));
/* compute y/x */
x=copysign(x,one);
Index: noieee_src/n_erf.c
===================================================================
RCS file: /cvs/src/lib/libm/noieee_src/n_erf.c,v
retrieving revision 1.7
diff -u -p -r1.7 n_erf.c
--- noieee_src/n_erf.c 27 Oct 2009 23:59:29 -0000 1.7
+++ noieee_src/n_erf.c 10 Sep 2016 20:30:34 -0000
@@ -255,7 +255,7 @@ double
erf(double x)
{
double R, S, P, Q, ax, s, y, z, r;
- if(!finite(x)) { /* erf(nan)=nan */
+ if(!isfinite(x)) { /* erf(nan)=nan */
if (isnan(x))
return(x);
return (x > 0 ? one : -one); /* erf(+/-inf)= +/-1 */
@@ -313,7 +313,7 @@ double
erfc(double x)
{
double R, S, P, Q, s, ax, y, z, r;
- if (!finite(x)) {
+ if (!isfinite(x)) {
if (isnan(x)) /* erfc(NaN) = NaN */
return(x);
else if (x > 0) /* erfc(+-inf)=0,2 */
Index: noieee_src/n_exp.c
===================================================================
RCS file: /cvs/src/lib/libm/noieee_src/n_exp.c,v
retrieving revision 1.10
diff -u -p -r1.10 n_exp.c
--- noieee_src/n_exp.c 27 Oct 2009 23:59:29 -0000 1.10
+++ noieee_src/n_exp.c 10 Sep 2016 20:30:35 -0000
@@ -37,7 +37,7 @@
* Required system supported functions:
* scalbn(x,n)
* copysign(x,y)
- * finite(x)
+ * isfinite(x)
*
* Method:
* 1. Argument Reduction: given the input x, find r and integer k such
@@ -115,7 +115,7 @@ exp(double x)
else
/* exp(-big#) underflows to zero */
- if(finite(x)) return(scalbn(1.0,-5000));
+ if(isfinite(x)) return(scalbn(1.0,-5000));
/* exp(-INF) is zero */
else return(0.0);
@@ -124,7 +124,7 @@ exp(double x)
else
/* exp(INF) is INF, exp(+big#) overflows to INF */
- return( finite(x) ? scalbn(1.0,5000) : x);
+ return( isfinite(x) ? scalbn(1.0,5000) : x);
}
/* returns exp(r = x + c) for |c| < |x| with no overlap. */
@@ -160,7 +160,7 @@ __exp__D(double x, double c)
else
/* exp(-big#) underflows to zero */
- if(finite(x)) return(scalbn(1.0,-5000));
+ if(isfinite(x)) return(scalbn(1.0,-5000));
/* exp(-INF) is zero */
else return(0.0);
@@ -169,5 +169,5 @@ __exp__D(double x, double c)
else
/* exp(INF) is INF, exp(+big#) overflows to INF */
- return( finite(x) ? scalbn(1.0,5000) : x);
+ return( isfinite(x) ? scalbn(1.0,5000) : x);
}
Index: noieee_src/n_expm1.c
===================================================================
RCS file: /cvs/src/lib/libm/noieee_src/n_expm1.c,v
retrieving revision 1.12
diff -u -p -r1.12 n_expm1.c
--- noieee_src/n_expm1.c 27 Oct 2009 23:59:29 -0000 1.12
+++ noieee_src/n_expm1.c 10 Sep 2016 20:30:35 -0000
@@ -38,7 +38,7 @@
* Required system supported functions:
* scalbn(x,n)
* copysign(x,y)
- * finite(x)
+ * isfinite(x)
*
* Kernel function:
* exp__E(x,c)
@@ -135,7 +135,7 @@ expm1(double x)
else
/* expm1(-big#) rounded to -1 (inexact) */
- if(finite(x))
+ if(isfinite(x))
return(tiny-one);
/* expm1(-INF) is -1 */
@@ -145,5 +145,5 @@ expm1(double x)
else
/* expm1(INF) is INF, expm1(+big#) overflows to INF */
- return( finite(x) ? scalbn(one,5000) : x);
+ return( isfinite(x) ? scalbn(one,5000) : x);
}
Index: noieee_src/n_floor.c
===================================================================
RCS file: /cvs/src/lib/libm/noieee_src/n_floor.c,v
retrieving revision 1.19
diff -u -p -r1.19 n_floor.c
--- noieee_src/n_floor.c 5 Jul 2013 05:44:10 -0000 1.19
+++ noieee_src/n_floor.c 10 Sep 2016 20:30:35 -0000
@@ -84,7 +84,7 @@ floorf(float x)
{
volatile float y;
- if (isnanf(x) || x >= F) /* already an even integer */
+ if (isnan(x) || x >= F) /* already an even integer */
return x;
else if (x < (float)0)
return -ceilf(-x);
@@ -100,7 +100,7 @@ ceilf(float x)
{
volatile float y;
- if (isnanf(x) || x >= F) /* already an even integer */
+ if (isnan(x) || x >= F) /* already an even integer */
return x;
else if (x < (float)0)
return -floorf(-x);
@@ -158,7 +158,7 @@ rintf(float x)
volatile float t;
const float one = 1.0f;
- if (isnanf(x))
+ if (isnan(x))
return (x);
if (copysignf(x, one) >= F) /* already an integer */
Index: noieee_src/n_fmod.c
===================================================================
RCS file: /cvs/src/lib/libm/noieee_src/n_fmod.c,v
retrieving revision 1.7
diff -u -p -r1.7 n_fmod.c
--- noieee_src/n_fmod.c 27 Oct 2009 23:59:29 -0000 1.7
+++ noieee_src/n_fmod.c 10 Sep 2016 20:30:35 -0000
@@ -65,7 +65,7 @@ fmod(double x, double y)
int ir,iy;
double r,w;
- if (y == (double)0 || isnan(y) || !finite(x))
+ if (y == (double)0 || isnan(y) || !isfinite(x))
return (x*y)/(x*y);
r = fabs(x);
Index: noieee_src/n_hypot.c
===================================================================
RCS file: /cvs/src/lib/libm/noieee_src/n_hypot.c,v
retrieving revision 1.4
diff -u -p -r1.4 n_hypot.c
--- noieee_src/n_hypot.c 15 Jul 2013 04:08:26 -0000 1.4
+++ noieee_src/n_hypot.c 10 Sep 2016 20:30:35 -0000
@@ -37,7 +37,7 @@
*
* Required system supported functions :
* copysign(x,y)
- * finite(x)
+ * isfinite(x)
* scalbn(x,N)
* sqrt(x)
*
@@ -104,8 +104,8 @@ hypot(double x, double y)
double t,r;
int exp;
- if(finite(x))
- if(finite(y))
+ if(isfinite(x))
+ if(isfinite(y))
{
x=copysign(x,one);
y=copysign(y,one);
@@ -141,7 +141,7 @@ hypot(double x, double y)
else if(isinf(x)) /* x is +-INF */
return (copysign(x,one));
- else if(finite(y))
+ else if(isfinite(y))
return(x); /* x is NaN, y is finite */
else if (isnan(y))
return (y);
@@ -161,8 +161,8 @@ hypot(double x, double y)
double temp;
int exp;
- if(finite(x))
- if(finite(y))
+ if(isfinite(x))
+ if(isfinite(y))
{
x=copysign(x,one);
y=copysign(y,one);
@@ -187,7 +187,7 @@ hypot(double x, double y)
else if(isinf(x)) /* x is +-INF */
return (copysign(x,one));
- else if(finite(y))
+ else if(isfinite(y))
return(x); /* x is NaN, y is finite */
else if(isnan(y)) return(y); /* x and y is NaN */
else return(copysign(y,one)); /* y is INF */
Index: noieee_src/n_j0.c
===================================================================
RCS file: /cvs/src/lib/libm/noieee_src/n_j0.c,v
retrieving revision 1.7
diff -u -p -r1.7 n_j0.c
--- noieee_src/n_j0.c 27 Oct 2009 23:59:29 -0000 1.7
+++ noieee_src/n_j0.c 10 Sep 2016 20:30:35 -0000
@@ -138,7 +138,7 @@ j0(double x)
{
double z, s,c,ss,cc,r,u,v;
- if (!finite(x))
+ if (!isfinite(x))
if (_IEEE) return one/(x*x);
else return (0);
x = fabs(x);
@@ -200,7 +200,7 @@ y0(double x)
{
double z, s, c, ss, cc, u, v;
/* Y0(NaN) is NaN, y0(-inf) is Nan, y0(inf) is 0 */
- if (!finite(x))
+ if (!isfinite(x))
if (_IEEE)
return (one/(x+x*x));
else
Index: noieee_src/n_j1.c
===================================================================
RCS file: /cvs/src/lib/libm/noieee_src/n_j1.c,v
retrieving revision 1.7
diff -u -p -r1.7 n_j1.c
--- noieee_src/n_j1.c 27 Oct 2009 23:59:29 -0000 1.7
+++ noieee_src/n_j1.c 10 Sep 2016 20:30:35 -0000
@@ -143,7 +143,7 @@ j1(double x)
{
double z, s,c,ss,cc,r,u,v,y;
y = fabs(x);
- if (!finite(x)) /* Inf or NaN */
+ if (!isfinite(x)) /* Inf or NaN */
if (isnan(x))
return(x);
else
@@ -206,7 +206,7 @@ y1(double x)
{
double z, s, c, ss, cc, u, v;
/* if Y1(NaN) is NaN, Y1(-inf) is NaN, Y1(inf) is 0 */
- if (!finite(x))
+ if (!isfinite(x))
if (x < 0)
return(zero/zero);
else if (x > 0)
Index: noieee_src/n_jn.c
===================================================================
RCS file: /cvs/src/lib/libm/noieee_src/n_jn.c,v
retrieving revision 1.7
diff -u -p -r1.7 n_jn.c
--- noieee_src/n_jn.c 27 Oct 2009 23:59:29 -0000 1.7
+++ noieee_src/n_jn.c 10 Sep 2016 20:30:35 -0000
@@ -122,7 +122,7 @@ jn(int n, double x)
if (n==1) return(j1(x));
sgn = (n&1)&(x < zero); /* even n -- 0, odd n -- sign(x) */
x = fabs(x);
- if (x == 0 || !finite (x)) /* if x is 0 or inf */
+ if (x == 0 || !isfinite (x)) /* if x is 0 or inf */
b = zero;
else if ((double) n <= x) {
/* Safe to use J(n+1,x)=2n/x *J(n,x)-J(n-1,x) */
@@ -261,7 +261,7 @@ yn(int n, double x)
else if (x < 0) return (infnan(EDOM));
else if (_IEEE) return -one/zero;
else return(infnan(-ERANGE));
- else if (!finite(x)) return(0);
+ else if (!isfinite(x)) return(0);
sign = 1;
if (n<0){
n = -n;
@@ -294,13 +294,13 @@ yn(int n, double x)
a = y0(x);
b = y1(x);
/* quit if b is -inf */
- for (i = 1; i < n && !finite(b); i++){
+ for (i = 1; i < n && !isfinite(b); i++){
temp = b;
b = ((double)(i+i)/x)*b - a;
a = temp;
}
}
- if (!_IEEE && !finite(b))
+ if (!_IEEE && !isfinite(b))
return (infnan(-sign * ERANGE));
return ((sign > 0) ? b : -b);
}
Index: noieee_src/n_lgamma.c
===================================================================
RCS file: /cvs/src/lib/libm/noieee_src/n_lgamma.c,v
retrieving revision 1.9
diff -u -p -r1.9 n_lgamma.c
--- noieee_src/n_lgamma.c 27 Oct 2009 23:59:29 -0000 1.9
+++ noieee_src/n_lgamma.c 10 Sep 2016 20:30:35 -0000
@@ -141,7 +141,7 @@ lgamma(double x)
endian = ((*(int *) &one)) ? 1 : 0;
#endif
- if (!finite(x))
+ if (!isfinite(x))
if (_IEEE)
return (x+x);
else return (infnan(EDOM));
@@ -197,7 +197,7 @@ large_lgam(double x)
v.b = (x - v.a) - 0.5;
t.a = u.a*v.a;
t.b = x*u.b + v.b*u.a;
- if (_IEEE == 0 && !finite(t.a))
+ if (_IEEE == 0 && !isfinite(t.a))
return(infnan(ERANGE));
return(t.a + t.b);
}
Index: noieee_src/n_log.c
===================================================================
RCS file: /cvs/src/lib/libm/noieee_src/n_log.c,v
retrieving revision 1.8
diff -u -p -r1.8 n_log.c
--- noieee_src/n_log.c 27 Oct 2009 23:59:29 -0000 1.8
+++ noieee_src/n_log.c 10 Sep 2016 20:30:35 -0000
@@ -375,7 +375,7 @@ log(double x)
return (infnan(-ERANGE));
else
return (infnan(EDOM));
- else if (!finite(x))
+ else if (!isfinite(x))
if (_IEEE) /* x = NaN, Inf */
return (x+x);
else
Index: noieee_src/n_pow.c
===================================================================
RCS file: /cvs/src/lib/libm/noieee_src/n_pow.c,v
retrieving revision 1.12
diff -u -p -r1.12 n_pow.c
--- noieee_src/n_pow.c 27 Oct 2009 23:59:29 -0000 1.12
+++ noieee_src/n_pow.c 10 Sep 2016 20:30:35 -0000
@@ -39,7 +39,7 @@
* scalbn(x,n)
* logb(x)
* copysign(x,y)
- * finite(x)
+ * isfinite(x)
* remainder(x,y)
*
* Required kernel functions:
@@ -127,7 +127,7 @@ pow(double x, double y)
return (x); /* if x is NaN or y=1 */
else if (isnan(y)) /* if y is NaN */
return (y);
- else if (!finite(y)) /* if y is INF */
+ else if (!isfinite(y)) /* if y is INF */
if ((t=fabs(x))==one) /* +-1 ** +-INF is NaN */
return (y - y);
else if (t>one)
@@ -175,7 +175,7 @@ pow_P(double x, double y)
return (infnan(ERANGE));
if (x == one)
return (one);
- if (!finite(x))
+ if (!isfinite(x))
if (y < zero)
return (zero);
else if (_IEEE)
Index: noieee_src/n_sincos.c
===================================================================
RCS file: /cvs/src/lib/libm/noieee_src/n_sincos.c,v
retrieving revision 1.14
diff -u -p -r1.14 n_sincos.c
--- noieee_src/n_sincos.c 15 Jul 2013 04:08:26 -0000 1.14
+++ noieee_src/n_sincos.c 10 Sep 2016 20:30:35 -0000
@@ -44,7 +44,7 @@ sin(double x)
{
double a,c,z;
- if(!finite(x)) /* sin(NaN) and sin(INF) must be NaN */
+ if(!isfinite(x)) /* sin(NaN) and sin(INF) must be NaN */
return x-x;
x=remainder(x,PI2); /* reduce x into [-PI,PI] */
a=copysign(x,one);
@@ -81,7 +81,7 @@ cos(double x)
{
double a,c,z,s = 1.0;
- if(!finite(x)) /* cos(NaN) and cos(INF) must be NaN */
+ if(!isfinite(x)) /* cos(NaN) and cos(INF) must be NaN */
return x-x;
x=remainder(x,PI2); /* reduce x into [-PI,PI] */
a=copysign(x,one);
Index: noieee_src/n_support.c
===================================================================
RCS file: /cvs/src/lib/libm/noieee_src/n_support.c,v
retrieving revision 1.23
diff -u -p -r1.23 n_support.c
--- noieee_src/n_support.c 15 Jul 2013 04:08:26 -0000 1.23
+++ noieee_src/n_support.c 10 Sep 2016 20:30:35 -0000
@@ -270,7 +270,7 @@ sqrt(double x)
}
/* sqrt(INF) is INF */
- if(!finite(x)) return(x);
+ if(!isfinite(x)) return(x);
/* scale x to [1,4) */
n=logb(x);
Index: noieee_src/n_tan.c
===================================================================
RCS file: /cvs/src/lib/libm/noieee_src/n_tan.c,v
retrieving revision 1.14
diff -u -p -r1.14 n_tan.c
--- noieee_src/n_tan.c 15 Jul 2013 04:08:26 -0000 1.14
+++ noieee_src/n_tan.c 10 Sep 2016 20:30:35 -0000
@@ -45,7 +45,7 @@ tan(double x)
double a,z,ss,cc,c;
int k;
- if(!finite(x)) /* tan(NaN) and tan(INF) must be NaN */
+ if(!isfinite(x)) /* tan(NaN) and tan(INF) must be NaN */
return x-x;
x = remainder(x,PI); /* reduce x into [-PI/2, PI/2] */
a = copysign(x,one); /* ... = abs(x) */
Index: noieee_src/n_tanh.c
===================================================================
RCS file: /cvs/src/lib/libm/noieee_src/n_tanh.c,v
retrieving revision 1.9
diff -u -p -r1.9 n_tanh.c
--- noieee_src/n_tanh.c 27 Oct 2009 23:59:29 -0000 1.9
+++ noieee_src/n_tanh.c 10 Sep 2016 20:30:35 -0000
@@ -39,7 +39,7 @@
*
* Required system supported functions :
* copysign(x,y)
- * finite(x)
+ * isfinite(x)
*
* Required kernel function:
* expm1(x) ...exp(x)-1
@@ -88,7 +88,7 @@ tanh(double x)
t = big + x;
return(copysign(x,sign) - (t-(big+x)));
}
- else if(finite(x))
+ else if(isfinite(x))
return (sign+1.0E-37); /* raise the INEXACT flag */
else
return(sign); /* x is +- INF */
Index: noieee_src/n_tgamma.c
===================================================================
RCS file: /cvs/src/lib/libm/noieee_src/n_tgamma.c,v
retrieving revision 1.4
diff -u -p -r1.4 n_tgamma.c
--- noieee_src/n_tgamma.c 27 Oct 2009 23:59:29 -0000 1.4
+++ noieee_src/n_tgamma.c 10 Sep 2016 20:30:35 -0000
@@ -161,7 +161,7 @@ tgamma(double x)
u.a = one - tiny; /* raise inexact */
}
return (one/x);
- } else if (!finite(x)) {
+ } else if (!isfinite(x)) {
if (_IEEE) /* x = NaN, -Inf */
return (x - x);
else
Index: src/b_exp__D.c
===================================================================
RCS file: /cvs/src/lib/libm/src/b_exp__D.c,v
retrieving revision 1.5
diff -u -p -r1.5 b_exp__D.c
--- src/b_exp__D.c 27 Oct 2009 23:59:29 -0000 1.5
+++ src/b_exp__D.c 10 Sep 2016 20:30:35 -0000
@@ -37,7 +37,7 @@
* Required system supported functions:
* scalb(x,n)
* copysign(x,y)
- * finite(x)
+ * isfinite(x)
*
* Method:
* 1. Argument Reduction: given the input x, find r and integer k such
@@ -110,7 +110,7 @@ __exp__D(double x, double c)
else
/* exp(-big#) underflows to zero */
- if(finite(x)) return(scalb(1.0,-5000));
+ if(isfinite(x)) return(scalb(1.0,-5000));
/* exp(-INF) is zero */
else return(0.0);
@@ -119,5 +119,5 @@ __exp__D(double x, double c)
else
/* exp(INF) is INF, exp(+big#) overflows to INF */
- return( finite(x) ? scalb(1.0,5000) : x);
+ return( isfinite(x) ? scalb(1.0,5000) : x);
}
Index: src/b_tgamma.c
===================================================================
RCS file: /cvs/src/lib/libm/src/b_tgamma.c,v
retrieving revision 1.8
diff -u -p -r1.8 b_tgamma.c
--- src/b_tgamma.c 3 Jul 2013 04:46:36 -0000 1.8
+++ src/b_tgamma.c 10 Sep 2016 20:30:35 -0000
@@ -138,7 +138,7 @@ tgamma(double x)
if (x != 0.0)
u.a = one - tiny; /* raise inexact */
return (one/x);
- } else if (!finite(x)) {
+ } else if (!isfinite(x)) {
return (x - x); /* x = NaN, -Inf */
} else
return (neg_gam(x));
Index: src/e_scalb.c
===================================================================
RCS file: /cvs/src/lib/libm/src/e_scalb.c,v
retrieving revision 1.4
diff -u -p -r1.4 e_scalb.c
--- src/e_scalb.c 27 Oct 2009 23:59:29 -0000 1.4
+++ src/e_scalb.c 10 Sep 2016 20:30:36 -0000
@@ -32,7 +32,7 @@ double
scalb(double x, double fn)
{
if (isnan(x)||isnan(fn)) return x*fn;
- if (!finite(fn)) {
+ if (!isfinite(fn)) {
if(fn>0.0) return x*fn;
else return x/(-fn);
}
Index: src/e_scalbf.c
===================================================================
RCS file: /cvs/src/lib/libm/src/e_scalbf.c,v
retrieving revision 1.4
diff -u -p -r1.4 e_scalbf.c
--- src/e_scalbf.c 27 Oct 2009 23:59:29 -0000 1.4
+++ src/e_scalbf.c 10 Sep 2016 20:30:36 -0000
@@ -28,8 +28,8 @@ scalbf(float x, int fn)
float
scalbf(float x, float fn)
{
- if (isnanf(x)||isnanf(fn)) return x*fn;
- if (!finitef(fn)) {
+ if (isnan(x)||isnan(fn)) return x*fn;
+ if (!isfinite(fn)) {
if(fn>(float)0.0) return x*fn;
else return x/(-fn);
}
Index: src/s_roundf.c
===================================================================
RCS file: /cvs/src/lib/libm/src/s_roundf.c,v
retrieving revision 1.1
diff -u -p -r1.1 s_roundf.c
--- src/s_roundf.c 12 Jul 2006 07:26:08 -0000 1.1
+++ src/s_roundf.c 10 Sep 2016 20:30:36 -0000
@@ -34,7 +34,7 @@ roundf(float x)
{
float t;
- if (isinff(x) || isnanf(x))
+ if (isinf(x) || isnan(x))
return (x);
if (x >= 0.0) {
Index: src/ld128/e_lgammal.c
===================================================================
RCS file: /cvs/src/lib/libm/src/ld128/e_lgammal.c,v
retrieving revision 1.3
diff -u -p -r1.3 e_lgammal.c
--- src/ld128/e_lgammal.c 9 Jul 2011 05:29:06 -0000 1.3
+++ src/ld128/e_lgammal.c 10 Sep 2016 20:30:36 -0000
@@ -764,7 +764,7 @@ lgammal(long double x)
signgam = 1;
- if (! finite (x))
+ if (! isfinite (x))
return x * x;
if (x == 0.0L)
Index: noieee_src/n_log1p.c
===================================================================
RCS file: /cvs/src/lib/libm/noieee_src/n_log1p.c,v
retrieving revision 1.11
diff -u -p -r1.11 n_log1p.c
--- noieee_src/n_log1p.c 27 Oct 2009 23:59:29 -0000 1.11
+++ noieee_src/n_log1p.c 10 Sep 2016 20:30:35 -0000
@@ -39,7 +39,7 @@
* scalbn(x,n)
* copysign(x,y)
* logb(x)
- * finite(x)
+ * isfinite(x)
*
* Required kernel function:
* log__L(z)
@@ -107,7 +107,7 @@ log1p(double x)
if (isnan(x))
return (x);
- if(finite(x)) {
+ if(isfinite(x)) {
if( x > negone ) {
/* argument reduction */
@@ -143,7 +143,7 @@ log1p(double x)
#endif /* defined(__vax__) */
}
}
/* end of if (finite(x)) */
/* log(-INF) is NaN */
else if(x<0)
@@ -143,7 +143,7 @@ log1p(double x)
}
}
- /* end of if (finite(x)) */
+ /* end of if (isfinite(x)) */
/* log(-INF) is NaN */
else if(x<0)